@@ -128,7 +128,9 @@ server = http.createServer(function (req, res) {
   // Process server request
   else if (new RegExp('(' + dirs.join('|') + ')\/server').test(url)) {
     if (fs.existsSync(path.join(__dirname, url + '.js'))) {
-      require(path.join(__dirname, url + '.js'))(req, res);
+      import('./' + url + '.js').then(module => {
+        module.default(req, res)
+      });
     } else {
       send404(res);
     }
